
# python modules used
import os
import string

# local modules used
import opusutil
import base_db

class Mission_db(base_db.Base_db):
  """
=======================================================================
Class: Mission_db 

Description:
------------
This class provides access to mission-independent relations in the 
mission database (e.g. OPUS, KEPLER).  These are typically related
to ingest functions.
It inherits common function from the base_db.Base_db class.

Methods:
--------

History:
--------
10/01/02 xxxxx MSwam     Initial version
07/15/10 65561 MSwam     replace db retry with unused default=0 parameter
=======================================================================
  """
  def __init__(self, server, dbname, notUsed=0):
    #
    # call Superclass constructor
    base_db.Base_db.__init__(self, server, dbname)


  def get_archive_class_map(self):
    """
=======================================================================
Name: get_archive_class_map

Description:
------------
This function returns a map of the archive_class and asn_class
keyed on data_id.

Arguments:
----------
DBobj (I)        - open database object that will execute the database query

Returns:
--------
dict = list of archive_class and asn_class values keyed by data_id

=======================================================================
    """
    # Name: get_archive_class_map
    #
    # build the query template
    querytxt = ("SELECT * FROM archive_class_map ")
    #
    # get results in a list of dictionaries
    result = [{}]
    self.zombie_select(querytxt, result)

    # convert to a dictionary of lists, keyed on data_id
    dict = {}
    for i in result:
      dict[i['acm_data_id']] = [i['acm_archive_class'],i['acm_asn_class']]
    return dict

  def get_members(self, groupname, data_id):
    """
=======================================================================
Name: get_members

Description:
------------
This function returns a list of the request_members rows for a given
groupname and data_id (returns member_name and data_id as list items).

Arguments:
----------
groupname
data_id

Returns:
--------
result = list of member_name of data_id values for the given groupname

History:
--------
06/08/04 51450  MSwam    add data_id as qualifier on query

=======================================================================
    """
    # def get_members(self, groupname, data_id):
    #
    # build the query template
    querytxt = ("SELECT rqm_member_name, rqm_data_id FROM request_members "+
                "WHERE "+
                "rqm_group_name = '"+groupname+"' and "+
                "rqm_data_id = '"+data_id+"'")
    #
    # get results in a list of lists
    result = [[]]
    self.zombie_select(querytxt, result)
    return result

  def get_valid_extensions(self):
    """
=======================================================================
Name: get_valid_extensions

Description:
------------
This function returns a list of data_id, extension, and valid_type fields
from the valid_extensions table.

Returns:
--------
result = list of all data_id, extension, valid_type from valid_extensions
         (fields are in a map, keyed by field name)

=======================================================================
    """
    # def get_valid_extensions(self):
    #
    # build the query template
    querytxt = ("SELECT vae_data_id, vae_extension, vae_valid_type FROM "+
                "valid_extensions ")
    #
    # get results in a list of maps
    result = [{}]
    self.zombie_select(querytxt, result)
    return result

#========================================================================
# TEST 
# % python missionquery.py
#========================================================================
if __name__ == "__main__":
  # connect to mission database
  mission_db = Mission_db(os.environ['MISSION_SERVER'], 
                os.environ['MISSION_DB'])

  opusutil.PrintMsg("I","archive_class_map="+
                    str(mission_db.get_archive_class_map()))
  opusutil.PrintMsg("I","members="+str(mission_db.get_members("u2440101t","wf2")))
  
  #
  result = mission_db.get_valid_extensions()
  opusutil.PrintMsg("I","valid_extensions="+str(result))
  mission_db.close()
